Chromium Code Reviews
chromiumcodereview-hr@appspot.gserviceaccount.com (chromiumcodereview-hr) | Please choose your nickname with Settings | Help | Chromium Project | Gerrit Changes | Sign out
(6032)

Unified Diff: chrome/browser/renderer_host/browser_render_process_host.h

Issue 6201005: Initial support for partitioning cookies for isolated apps. (Closed) Base URL: svn://svn.chromium.org/chrome/trunk/src
Patch Set: Fix automation_util and thread issue. Created 9 years, 9 months ago
Use n/p to move between diff chunks; N/P to move between comments. Draft comments are only viewable by you.
Jump to:
View side-by-side diff with in-line comments
Download patch
Index: chrome/browser/renderer_host/browser_render_process_host.h
diff --git a/chrome/browser/renderer_host/browser_render_process_host.h b/chrome/browser/renderer_host/browser_render_process_host.h
index e70263e5b5c9add867418d69276970fe12e307ad..cc1e8428ac32926ba9b504c8522eefaaa9cdcdce 100644
--- a/chrome/browser/renderer_host/browser_render_process_host.h
+++ b/chrome/browser/renderer_host/browser_render_process_host.h
@@ -23,6 +23,7 @@
#include "third_party/WebKit/Source/WebKit/chromium/public/WebCache.h"
class CommandLine;
+class Extension;
class RendererMainThread;
class RenderWidgetHelper;
class VisitedLinkUpdater;
@@ -53,7 +54,9 @@ class BrowserRenderProcessHost : public RenderProcessHost,
~BrowserRenderProcessHost();
// RenderProcessHost implementation (public portion).
- virtual bool Init(bool is_accessibility_enabled, bool is_extensions_process);
+ virtual bool Init(bool is_accessibility_enabled,
+ bool is_extensions_process,
+ const Extension* installed_app);
virtual int GetNextRoutingID();
virtual void CancelResourceRequests(int render_widget_id);
virtual void CrossSiteClosePageACK(const ViewMsg_ClosePage_Params& params);
@@ -199,7 +202,10 @@ class BrowserRenderProcessHost : public RenderProcessHost,
// when running in single-process mode.
bool extension_process_;
- // Usedt to launch and terminate the process without blocking the UI thread.
+ // The Extension for the hosted or packaged app if any, NULL otherwise.
+ scoped_refptr<const Extension> installed_app_;
+
+ // Used to launch and terminate the process without blocking the UI thread.
scoped_ptr<ChildProcessLauncher> child_process_;
// Messages we queue while waiting for the process handle. We queue them here

Powered by Google App Engine
This is Rietveld 408576698